diff --git a/exposurelib/database.py b/exposurelib/database.py
index 46d35fc11e4db8eda29bd0e31b0dae2e1ea0f074..80b1a51e46d149930040dc45aac1e8ed77a9d417 100644
--- a/exposurelib/database.py
+++ b/exposurelib/database.py
@@ -28,6 +28,7 @@ from taxonomylib.taxonomylib import Taxonomy
 from databaselib.database import AbstractDatabase, SpatiaLiteDatabase, PostGISDatabase
 from pygeotile.tile import Tile
 from collections import namedtuple
+from collections.abc import Iterable
 
 
 logger = logging.getLogger(__name__)
@@ -797,13 +798,13 @@ class AbstractExposure(AbstractDatabase, ABC):
             raise ValueError(f"{boundary_id}: Boundary does not exist in the database.")
         return result[0]
 
-    def get_country_buildings_iter(self, country_iso_code):
+    def get_country_buildings_iter(self, country_iso_code: str) -> Iterable:
         """
         Provides an iterator over all buildings of a country. An additional buffer of 500m is
         applied to the country boundary to account for building centroids outside the regular
         boundary but inside of tiles whose centroids are inside the regular boundary. The
-        iterator delivers the OSM ID, Quadkey, occupancy, number of stories, floorspace and the
-        geometry of the selected buildings.
+        iterator delivers the OSM ID, Quadkey, occupancy, height, floorspace and the geometry of
+        the selected buildings.
 
         Args:
             country_iso_code (str):
@@ -813,16 +814,16 @@ class AbstractExposure(AbstractDatabase, ABC):
             Iterator over all buildings within a country.
         """
 
-        # Retrieve country boundary with 500m buffer to include buildings located outside the
-        # country but inside a tile whose centroid is inside the country
+        # Retrieve the country boundary with 500m buffer to include buildings located outside
+        # the country but inside a tile whose centroid is inside the country.
         boundary_geometry = self.get_country_boundary_geometry(country_iso_code, buffer=500)
 
-        # Query buildings within the given boundary
+        # Query buildings within the given boundary.
         sql_statement = f"""
         WITH SelectedBoundary(boundary_geometry) AS (
             VALUES (ST_GeomFromText('{boundary_geometry}', 4326))
         )
-        SELECT osm_id, quadkey, occupancy, storeys, floorspace, ST_AsText({self.geometry_field})
+        SELECT osm_id, quadkey, occupancy, height, floorspace, ST_AsText({self.geometry_field})
         FROM {self.building_table}
         INNER JOIN SelectedBoundary
         ON ST_Contains(
@@ -837,9 +838,9 @@ class AbstractExposure(AbstractDatabase, ABC):
             """
         self.cursor.execute(sql_statement)
 
-        # Return the generator
-        for osm_id, quadkey, occupancy, stories, floorspace, geom_wkt in self.cursor:
-            yield osm_id, quadkey, occupancy, stories, floorspace, geom_wkt
+        # Return the iterator.
+        for osm_id, quadkey, occupancy, height, floorspace, geom_wkt in self.cursor:
+            yield osm_id, quadkey, occupancy, height, floorspace, geom_wkt
 
     def get_country_boundary_geometry(self, country_iso_code, buffer=None):
         """